package actinScope;
/*
 * ConcControlFrame... vary concentrations of molecular species
*/
/*  <ActinScope - for the simulation of dendritic actin networks>
    Copyright (C) <2005>  <Jonathan B. Alberts>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.event.*;

public class ConcControlFrame extends JFrame implements ChangeListener, ActionListener, WindowListener, ComponentListener, KeyListener, MouseListener, MouseMotionListener, AdjustmentListener {
	static ActinScope parentSim;
	static JPanel titlePanel,concPanel,applyPanel;
	static ParamGui [] concs = new ParamGui[10];
	static int concCt = 0;
	
	public ConcControlFrame (ActinScope parentSim) {
		ConcControlFrame.parentSim = parentSim;
		
		makeTitlePanel();
		makeRatesPanel();
		makeApplyPanel();
		
		addKeyListener(this);
		addComponentListener(this);
		addMouseListener(this);
		addMouseMotionListener(this);
		addWindowListener(this);
		
		initialize();
		Dimension prefDim = getPreferredSize();
		prefDim.height += (concCt+1)*10;
		setSize(prefDim);
		
	
	}
	
	public void initialize () {
		getContentPane().removeAll();
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add (titlePanel, BorderLayout.NORTH);
		getContentPane().add (concPanel, BorderLayout.CENTER);
		getContentPane().add (applyPanel, BorderLayout.SOUTH);
		
	}
	
	public void setInfoFields () {
		for (int i=0;i<concCt;i++) {
			concs[i].refreshField();
		}
	}
	
	public void refreshAll () {
		for (int i=0;i<concCt;i++) { concs[i].refreshField(); }
	}
	
	public void revertAll () {
		for (int i=0;i<concCt;i++) { concs[i].setToDefaultValue(); }
	}
	
	public void lastValueAll () {
		for (int i=0;i<concCt;i++) { concs[i].setToLastValue(); }
	}
	
	public void actionPerformed (ActionEvent e) {
		String act = e.getActionCommand();
		
		if (act.equals("Apply")) {
			for (int i=0;i<concCt;i++) { concs[i].setValueFromGui(); }
			refreshAll();
		}
		
		if (act.equals("Revert")) {
			revertAll();
		}
		
		if (act.equals("Cancel")) {
			refreshAll();
		}
		
	}
	
	public void stateChanged(ChangeEvent e) {
	}
	
	public void adjustmentValueChanged (AdjustmentEvent e) {
	}
	
	
	public void windowActivated (WindowEvent e) {}
	public void windowClosing (WindowEvent e) {}
	public void windowDeactivated (WindowEvent e) {}
	public void windowDeiconified (WindowEvent e) {}
	public void windowIconified (WindowEvent e) {}
	public void windowOpened (WindowEvent e) {}
	public void windowClosed (WindowEvent e) {}
	
	public void keyReleased (KeyEvent e) {}
	public void keyTyped (KeyEvent e) {}
	public void keyPressed (KeyEvent e) {
		String act = e.getKeyText(e.getKeyCode());
	}
	
	public void mouseClicked (MouseEvent e) {}
	public void mouseEntered (MouseEvent e) {}
	public void mouseExited (MouseEvent e) {}
	public void mousePressed (MouseEvent e) {
		int xPos = e.getX();
		int yPos = e.getY();
	}
	
	public void mouseReleased (MouseEvent e) {}
	public void mouseDragged (MouseEvent e) {}
	public void mouseMoved (MouseEvent e) {}
	
	public void componentHidden (ComponentEvent e) {}
	public void componentShown (ComponentEvent e) {}
	public void componentMoved (ComponentEvent e) {}
	public void componentResized (ComponentEvent e) {}
	
	public void makeTitlePanel () {
		titlePanel = new JPanel();
		titlePanel.setBackground(Env.controlBackColor);
		JLabel titleLabel = new JLabel("Concentrations");
		titleLabel.setForeground(Env.controlForeColor);
		titlePanel.add(titleLabel);
	}
	
	private void addConc (ParamGui newConc) {
		concs[concCt] = newConc;
		concCt++;
	}
	
	public void makeRatesPanel() {
		concPanel = new JPanel();
		concPanel.setBackground(Env.controlBackColor);
		
		InertGuiHead depleteHead = new InertGuiHead(" deplete"," "," ");
		
		addConc(new ParamGui(Env.actinConc,ParamGui.CHECKBOX_ON));
		addConc(new ParamGui(Env.arpConc,ParamGui.CHECKBOX_ON));
		addConc(new ParamGui(Env.capConc,ParamGui.CHECKBOX_ON));

		concPanel.setLayout(new GridLayout(concCt+1,3));
		depleteHead.addToPanel(concPanel);
	
		for (int i=0;i<concCt;i++) {
			concs[i].addToPanel(concPanel);
		}
		
	}
	
	public void makeApplyPanel () {
		applyPanel = new JPanel();
		applyPanel.setBackground(Env.controlBackColor);
	
		JButton cancelB = new JButton ("Cancel");
		cancelB.setActionCommand("Cancel");
		cancelB.setToolTipText("Cancel these changes");
		cancelB.addActionListener(this);
		cancelB.setBackground(Env.controlBackColor);
		cancelB.setForeground(Env.controlForeColor);
		cancelB.setBorder(BorderFactory.createEmptyBorder());
		cancelB.setEnabled(true);
		
		JButton revertB = new JButton ("Revert");
		revertB.setActionCommand("Revert");
		revertB.setToolTipText("Revert to default values");
		revertB.addActionListener(this);
		revertB.setBackground(Env.controlBackColor);
		revertB.setForeground(Env.controlForeColor);
		revertB.setBorder(BorderFactory.createEmptyBorder());
		revertB.setEnabled(true);
		
		JButton applyB = new JButton("Apply");
		applyB.setActionCommand("Apply");
		applyB.setToolTipText("Apply Changes");
		applyB.addActionListener(this);
		applyB.setBackground(Env.controlBackColor);
		applyB.setForeground(Env.controlForeColor);
		applyB.setBorder(BorderFactory.createEmptyBorder());
		applyB.setEnabled(true);
		
		applyPanel.setLayout(new FlowLayout(FlowLayout.CENTER,10,10));
		applyPanel.add(cancelB);
		applyPanel.add(revertB);
		applyPanel.add(applyB);
		
	}
}

