package actinScope;
/*
 * InitControlFrame... vary initial conditions for the run
*/
/*  <ActinScope - for the simulation of dendritic actin networks>
    Copyright (C) <2005>  <Jonathan B. Alberts>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.awt.*;
import java.awt.event.*;
import java.lang.Math;
import javax.swing.*;
import javax.swing.event.*;

import java.io.*;
import java.text.*;
import java.util.*;
import javax.media.j3d.*;

public class InitControlFrame extends JFrame implements ChangeListener, ActionListener, WindowListener, ComponentListener, KeyListener, MouseListener, MouseMotionListener, AdjustmentListener {
	static ActinScope parentSim;
	static JPanel titlePanel,initsPanel,applyPanel;
	static ParamGui [] inits = new ParamGui[10];
	static int initCt = 0;
	
	public InitControlFrame (ActinScope parentSim) {
		this.parentSim = parentSim;
		
		makeTitlePanel();
		makeInitsPanel();
		makeApplyPanel();
		
		addKeyListener(this);
		addComponentListener(this);
		addMouseListener(this);
		addMouseMotionListener(this);
		addWindowListener(this);
		
		initialize();
		Dimension prefDim = getPreferredSize();
		prefDim.height += (initCt+1)*10;
		setSize(prefDim);
		
	}
	
	public void initialize () {
		getContentPane().removeAll();
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add (titlePanel, BorderLayout.NORTH);
		getContentPane().add (initsPanel, BorderLayout.CENTER);
		getContentPane().add (applyPanel, BorderLayout.SOUTH);
	}
	
	public void setInfoFields () {
		for (int i=0;i<initCt;i++) {
			inits[i].refreshField();
		}
	}
	
	public void refreshAll () {
		for (int i=0;i<initCt;i++) { inits[i].refreshField(); }
	}
	
	public void revertAll () {
		for (int i=0;i<initCt;i++) { inits[i].setToDefaultValue(); }
	}

	public void actionPerformed (ActionEvent e) {
		String act = e.getActionCommand();
		
		if (act.equals("Apply")) {
			for (int i=0;i<initCt;i++) { inits[i].setValueFromGui(); }
			refreshAll();
		}
		
		if (act.equals("Revert")) {
			revertAll();
		}
		
		if (act.equals("Cancel")) {
			refreshAll();
		}
		
	}
	
	public void stateChanged(ChangeEvent e) {
	    JSlider source = (JSlider)e.getSource();
	}
	
	public void adjustmentValueChanged (AdjustmentEvent e) {
	}
	
	
	public void windowActivated (WindowEvent e) {}
	public void windowClosing (WindowEvent e) {}
	public void windowDeactivated (WindowEvent e) {}
	public void windowDeiconified (WindowEvent e) {}
	public void windowIconified (WindowEvent e) {}
	public void windowOpened (WindowEvent e) {}
	public void windowClosed (WindowEvent e) {}
	
	public void keyReleased (KeyEvent e) {}
	public void keyTyped (KeyEvent e) {}
	public void keyPressed (KeyEvent e) {
		String act = e.getKeyText(e.getKeyCode());
	}
	
	public void mouseClicked (MouseEvent e) {}
	public void mouseEntered (MouseEvent e) {}
	public void mouseExited (MouseEvent e) {}
	public void mousePressed (MouseEvent e) {
		int xPos = e.getX();
		int yPos = e.getY();
	}
	
	public void mouseReleased (MouseEvent e) {}
	public void mouseDragged (MouseEvent e) {}
	public void mouseMoved (MouseEvent e) {}
	
	public void componentHidden (ComponentEvent e) {}
	public void componentShown (ComponentEvent e) {}
	public void componentMoved (ComponentEvent e) {}
	public void componentResized (ComponentEvent e) {}
	
	public void makeTitlePanel () {
		titlePanel = new JPanel();
		titlePanel.setBackground(Env.controlBackColor);
		JLabel titleLabel = new JLabel("Initial Conditions");
		titleLabel.setForeground(Env.controlForeColor);
		titlePanel.add(titleLabel);
	}
	
	private void addInit (ParamGui newInit) {
		inits[initCt] = newInit;
		initCt++;
	}
	
	public void makeInitsPanel() {
		initsPanel = new JPanel();
		initsPanel.setBackground(Env.controlBackColor);
		
		//InertGuiHead actinHead = new InertGuiHead("Actin inits","","");
		
		addInit(new ParamGui(Env.cellX));
		addInit(new ParamGui(Env.cellY));
		addInit(new ParamGui(Env.cellZ));
		
		addInit(new ParamGui(Env.pistDist));
		addInit(new ParamGui(Env.initSeeds));

		initsPanel.setLayout(new GridLayout(5,3));
		
		for (int i=0;i<initCt;i++) { inits[i].addToPanel(initsPanel); }
		
	}
	
	public void makeApplyPanel () {
		applyPanel = new JPanel();
		applyPanel.setBackground(Env.controlBackColor);
	
		BareButton cancelB = new BareButton ("Cancel");
		cancelB.setActionCommand("Cancel");
		cancelB.setToolTipText("Cancel these changes");
		cancelB.addActionListener(this);
		cancelB.setEnabled(true);
		
		BareButton revertB = new BareButton ("Revert");
		revertB.setActionCommand("Revert");
		revertB.setToolTipText("Revert to default values");
		revertB.addActionListener(this);
		revertB.setEnabled(true);
		
		BareButton applyB = new BareButton("Apply");
		applyB.setActionCommand("Apply");
		applyB.setToolTipText("Apply Changes");
		applyB.addActionListener(this);
		applyB.setEnabled(true);
		
		applyPanel.setLayout(new FlowLayout(FlowLayout.CENTER,10,10));
		applyPanel.add(cancelB);
		applyPanel.add(revertB);
		applyPanel.add(applyB);
		
	}
}
