package actinScope;
/*
 * RatesControlFrame... vary biochemical reaction rates
*/
/*  <ActinScope - for the simulation of dendritic actin networks>
    Copyright (C) <2005>  <Jonathan B. Alberts>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.awt.*;
import java.awt.event.*;
import java.lang.Math;
import javax.swing.*;
import javax.swing.event.*;

import java.io.*;
import java.text.*;
import java.util.*;
import javax.media.j3d.*;

public class MechControlFrame extends JFrame implements ChangeListener, ActionListener, WindowListener, ComponentListener, KeyListener, MouseListener, MouseMotionListener, AdjustmentListener {
	static ActinScope parentSim;
	static MenuBar parentMenu;
	static JPanel titlePanel,mechsPanel,applyPanel;
	static ParamGui [] mechs = new ParamGui[10];
	static int mechCt = 0;
	
	public MechControlFrame (ActinScope parentSim) {
		this.parentSim = parentSim;
		
		makeTitlePanel();
		makeMechsPanel();
		makeApplyPanel();
		
		addKeyListener(this);
		addComponentListener(this);
		addMouseListener(this);
		addMouseMotionListener(this);
		addWindowListener(this);
		
		initialize();
		Dimension prefDim = getPreferredSize();
		prefDim.height += (mechCt+1)*10;
		setSize(prefDim);
		
	}
	
	public void initialize () {
		getContentPane().removeAll();
		getContentPane().setLayout(new BorderLayout());
		getContentPane().add (titlePanel, BorderLayout.NORTH);
		getContentPane().add (mechsPanel, BorderLayout.CENTER);
		getContentPane().add (applyPanel, BorderLayout.SOUTH);
	
	}
	
	public void setInfoFields () {
		for (int i=0;i<mechCt;i++) {
			mechs[i].refreshField();
		}
	}
	
	public void refreshAll () {
		for (int i=0;i<mechCt;i++) { mechs[i].refreshField(); }
	}
	
	public void revertAll () {
		for (int i=0;i<mechCt;i++) { mechs[i].setToDefaultValue(); }
	}

	public void actionPerformed (ActionEvent e) {
		String act = e.getActionCommand();
		
		if (act.equals("Apply")) {
			for (int i=0;i<mechCt;i++) { mechs[i].setValueFromGui(); }
			refreshAll();
		}
		
		if (act.equals("Revert")) {
			revertAll();
		}
		
		if (act.equals("Cancel")) {
			refreshAll();
		}
		
	}
	
	public void stateChanged(ChangeEvent e) {
	    JSlider source = (JSlider)e.getSource();
	}
	
	public void adjustmentValueChanged (AdjustmentEvent e) {
	}
	
	
	public void windowActivated (WindowEvent e) {}
	public void windowClosing (WindowEvent e) {}
	public void windowDeactivated (WindowEvent e) {}
	public void windowDeiconified (WindowEvent e) {}
	public void windowIconified (WindowEvent e) {}
	public void windowOpened (WindowEvent e) {}
	public void windowClosed (WindowEvent e) {}
	
	public void keyReleased (KeyEvent e) {}
	public void keyTyped (KeyEvent e) {}
	public void keyPressed (KeyEvent e) {
		String act = e.getKeyText(e.getKeyCode());
	}
	
	public void mouseClicked (MouseEvent e) {}
	public void mouseEntered (MouseEvent e) {}
	public void mouseExited (MouseEvent e) {}
	public void mousePressed (MouseEvent e) {
		int xPos = e.getX();
		int yPos = e.getY();
	}
	
	public void mouseReleased (MouseEvent e) {}
	public void mouseDragged (MouseEvent e) {}
	public void mouseMoved (MouseEvent e) {}
	
	public void componentHidden (ComponentEvent e) {}
	public void componentShown (ComponentEvent e) {}
	public void componentMoved (ComponentEvent e) {}
	public void componentResized (ComponentEvent e) {}
	
	public void makeTitlePanel () {
		titlePanel = new JPanel();
		titlePanel.setBackground(Env.controlBackColor);
		JLabel titleLabel = new JLabel("Mechanism/Morphology");
		titleLabel.setForeground(Env.controlForeColor);
		titlePanel.add(titleLabel);
	}
	
	private void addMech (ParamGui newRate) {
		mechs[mechCt] = newRate;
		mechCt++;
	}
	
	public void makeMechsPanel() {
		mechsPanel = new JPanel();
		mechsPanel.setBackground(Env.controlBackColor);
		
		InertGuiHead polyHead = new InertGuiHead(" Polymerization","","");
		InertGuiHead branchHead = new InertGuiHead(" Branching","","");
		
		ParamGui polyGapGui = new ParamGui(Env.polyGap);
		polyGapGui.setFieldType(ParamGui.FRACNANOS_FORMAT);
		addMech(polyGapGui);
		
		addMech(new ParamGui(Env.branchAng));
		addMech(new ParamGui(Env.branchAngVar));
		addMech(new ParamGui(Env.branchBarbedZone));
		addMech(new ParamGui(Env.branchMinDist));

		mechsPanel.setLayout(new GridLayout(7,3));
		
		polyHead.addToPanel(mechsPanel);
		mechs[0].addToPanel(mechsPanel);
		
		branchHead.addToPanel(mechsPanel);
		for (int i=1;i<5;i++) { mechs[i].addToPanel(mechsPanel); }
	
	}
	
	public void makeApplyPanel () {
		applyPanel = new JPanel();
		applyPanel.setBackground(Env.controlBackColor);
	
		BareButton cancelB = new BareButton ("Cancel");
		cancelB.setActionCommand("Cancel");
		cancelB.setToolTipText("Cancel these changes");
		cancelB.addActionListener(this);
		cancelB.setEnabled(true);
		
		BareButton revertB = new BareButton ("Revert");
		revertB.setActionCommand("Revert");
		revertB.setToolTipText("Revert to default values");
		revertB.addActionListener(this);
		revertB.setEnabled(true);
		
		BareButton applyB = new BareButton("Apply");
		applyB.setActionCommand("Apply");
		applyB.setToolTipText("Apply Changes");
		applyB.addActionListener(this);
		applyB.setEnabled(true);
		
		applyPanel.setLayout(new FlowLayout(FlowLayout.CENTER,10,10));
		applyPanel.add(cancelB);
		applyPanel.add(revertB);
		applyPanel.add(applyB);
		
	}
}
